==> rsass_0.28.8.orig.tar.gz: rsass-0.28.8/rsass/tests/spec/core_functions/color/hwb/three_args/w3c/yellows.rs <==
//! Tests auto-converted from "sass-spec/spec/core_functions/color/hwb/three_args/w3c/yellows.hrx"

#[allow(unused)]
fn runner() -> crate::TestRunner {
    super::runner().with_cwd("yellows")
}

#[test]
fn test() {
    assert_eq!(
        runner().ok("@use \'../test-hue\' as *;\
             \n@include test-hue(60);\n"),
        "whiteness-0 {\
         \n  blackness-0: yellow;\
         \n  blackness-20: #cccc00;\
         \n  blackness-40: #999900;\
         \n  blackness-60: #666600;\
         \n  blackness-80: #333300;\
         \n  blackness-100: black;\
         \n}\
         \nwhiteness-20 {\
         \n  blackness-0: #ffff33;\
         \n  blackness-20: #cccc33;\
         \n  blackness-40: #999933;\
         \n  blackness-60: #666633;\
         \n  blackness-80: #333333;\
         \n  blackness-100: #2b2b2b;\
         \n}\
         \nwhiteness-40 {\
         \n  blackness-0: #ffff66;\
         \n  blackness-20: #cccc66;\
         \n  blackness-40: #999966;\
         \n  blackness-60: #666666;\
         \n  blackness-80: #555555;\
         \n  blackness-100: #494949;\
         \n}\
         \nwhiteness-60 {\
         \n  blackness-0: #ffff99;\
         \n  blackness-20: #cccc99;\
         \n  blackness-40: #999999;\
         \n  blackness-60: gray;\
         \n  blackness-80: #6d6d6d;\
         \n  blackness-100: #606060;\
         \n}\
         \nwhiteness-80 {\
         \n  blackness-0: #ffffcc;\
         \n  blackness-20: #cccccc;\
         \n  blackness-40: #aaaaaa;\
         \n  blackness-60: #929292;\
         \n  blackness-80: gray;\
         \n  blackness-100: #717171;\
         \n}\
         \nwhiteness-100 {\
         \n  blackness-0: white;\
         \n  blackness-20: #d5d5d5;\
         \n  blackness-40: #b6b6b6;\
         \n  blackness-60: #9f9f9f;\
         \n  blackness-80: #8e8e8e;\
         \n  blackness-100: gray;\
         \n}\n"
    );
}

==> rsass_0.29.0.orig.tar.gz: rsass-0.29.0/rsass/tests/spec/core_functions/color/hwb/three_args/w3c/yellows.rs <==
//! Tests auto-converted from "sass-spec/spec/core_functions/color/hwb/three_args/w3c/yellows.hrx"

#[allow(unused)]
fn runner() -> crate::TestRunner {
    super::runner().with_cwd("yellows")
}

#[test]
fn test() {
    assert_eq!(
        runner().ok("@use \'../test-hue\' as *;\
             \n@include test-hue(60);\n"),
        "whiteness-0 {\
         \n  blackness-0: yellow;\
         \n  blackness-20: #cccc00;\
         \n  blackness-40: #999900;\
         \n  blackness-60: #666600;\
         \n  blackness-80: #333300;\
         \n  blackness-100: black;\
         \n}\
         \nwhiteness-20 {\
         \n  blackness-0: #ffff33;\
         \n  blackness-20: #cccc33;\
         \n  blackness-40: #999933;\
         \n  blackness-60: #666633;\
         \n  blackness-80: #333333;\
         \n  blackness-100: hsl(0, 0%, 16.6666666667%);\
         \n}\
         \nwhiteness-40 {\
         \n  blackness-0: #ffff66;\
         \n  blackness-20: #cccc66;\
         \n  blackness-40: #999966;\
         \n  blackness-60: #666666;\
         \n  blackness-80: #555555;\
         \n  blackness-100: hsl(0, 0%, 28.5714285714%);\
         \n}\
         \nwhiteness-60 {\
         \n  blackness-0: #ffff99;\
         \n  blackness-20: #cccc99;\
         \n  blackness-40: #999999;\
         \n  blackness-60: hsl(0, 0%, 50%);\
         \n  blackness-80: hsl(0, 0%, 42.8571428571%);\
         \n  blackness-100: hsl(0, 0%, 37.5%);\
         \n}\
         \nwhiteness-80 {\
         \n  blackness-0: #ffffcc;\
         \n  blackness-20: #cccccc;\
         \n  blackness-40: #aaaaaa;\
         \n  blackness-60: hsl(0, 0%, 57.1428571429%);\
         \n  blackness-80: hsl(0, 0%, 50%);\
         \n  blackness-100: hsl(0, 0%, 44.4444444444%);\
         \n}\
         \nwhiteness-100 {\
         \n  blackness-0: white;\
         \n  blackness-20: hsl(0, 0%, 83.3333333333%);\
         \n  blackness-40: hsl(0, 0%, 71.4285714286%);\
         \n  blackness-60: hsl(0, 0%, 62.5%);\
         \n  blackness-80: hsl(0, 0%, 55.5555555556%);\
         \n  blackness-100: hsl(0, 0%, 50%);\
         \n}\n"
    );
}
